Test Click

TestClickJavaScriptHref
open | ../tests/html/test_click_javascript_page.html |

Click a regular link

click | link |
verifyAlert | link clicked: foo |

Click link with multiple javascript calls

click | linkWithMultipleJavascriptStatements |
verifyAlert | alert1 |
verifyAlert | alert2 |
verifyAlert | alert3 |

Click a link with javascript:void() href

click | linkWithJavascriptVoidHref |
verifyAlert | onclick |
verifyTitle | Click Page 1 |

Click a link where onclick returns false

click | linkWithOnclickReturnsFalse |
verifyTitle | Click Page 1 |

No alert should be raised.

Click an image enclosed in a link

click | enclosedImage |
verifyAlert | enclosedImage clicked |